yetki library

Classes

Permission
Represents a permission in the RBAC system.
Role
Represents a role in the RBAC system.
Yetki
Yetki is a Role Based Access Control (RBAC) library for Dart. It provides a simple and flexible way to manage roles and permissions with optional caching and singleton instance capabilities.
YetkiUser
Represents a user in the RBAC system.

Exceptions / Errors

YetkiException
Custom exception class for Yetki-related errors.